@@ -66,13 +66,13 @@ from .errors import (
 from .utils.aid_bvid_transformer import aid2bvid, bvid2aid
 from .utils.Credential import Credential
 from .utils.Danmaku import Danmaku, DmFontSize, DmMode, SpecialDanmaku
-from .utils.network_httpx import HEADERS, get_session, set_session
+from .utils.network_httpx import HEADERS, get_session, set_session, retry
 from .utils.parse_link import ResourceType, parse_link
 from .utils.Picture import Picture
 from .utils.short import get_real_url
 from .utils.sync import sync
 
-BILIBILI_API_VERSION = "15.4.3"
+BILIBILI_API_VERSION = "15.4.4"
 
 # 如果系统为 Windows，则修改默认策略，以解决代理报错问题
 if "windows" in platform.system().lower():
@@ -137,6 +137,7 @@ __all__ = [
     "parse_link",
     "platform",
     "rank",
+    "retry",
     "search",
     "session",
     "set_session",
